@@ -5,6 +5,7 @@ import pandas as pd
 from ..util import _is_na, _normalize_counts
 from typing import Sequence
 from .._compat import Literal
+from ..io._util import _check_upgrade_schema
 
 
 def _group_abundance(
@@ -63,6 +64,7 @@ def _group_abundance(
     return result_df
 
 
+@_check_upgrade_schema()
 def group_abundance(
     adata: AnnData,
     groupby: str,
