@@ -1,13 +1,12 @@
 # pylama:ignore=W0611,W0404
 import pandas as pd
-import scirpy as st
+import scirpy as ir
 from scanpy import AnnData
 import pytest
 import numpy.testing as npt
 import pandas.testing as pdt
 import numpy as np
 import itertools
-from scirpy.util import _get_from_uns
 from .fixtures import adata_clonotype, adata_tra, adata_vdj, adata_diversity
 
 
@@ -29,10 +28,10 @@ def test_chain_pairing():
         columns=[
             "has_ir",
             "multi_chain",
-            "IR_VJ_1_cdr3",
-            "IR_VJ_2_cdr3",
-            "IR_VDJ_1_cdr3",
-            "IR_VDJ_2_cdr3",
+            "IR_VJ_1_junction_aa",
+            "IR_VJ_2_junction_aa",
+            "IR_VDJ_1_junction_aa",
+            "IR_VDJ_2_junction_aa",
             "IR_VJ_1_locus",
             "IR_VJ_2_locus",
             "IR_VDJ_1_locus",
@@ -40,7 +39,8 @@ def test_chain_pairing():
         ],
     )
     adata = AnnData(obs=obs)
-    res = st.tl.chain_pairing(adata, inplace=False)
+    adata.uns["scirpy_version"] = "0.7"
+    res = ir.tl.chain_pairing(adata, inplace=False)
     npt.assert_equal(
         res,
         [
@@ -91,13 +91,14 @@ def test_chain_qc():
     )
     # fake chains
     for chain, chain_number in itertools.product(["VJ", "VDJ"], ["1", "2"]):
-        obs[f"IR_{chain}_{chain_number}_cdr3"] = [
+        obs[f"IR_{chain}_{chain_number}_junction_aa"] = [
             "AAA" if x != "nan" else "nan"
             for x in obs[f"IR_{chain}_{chain_number}_locus"]
         ]
     adata = AnnData(obs=obs)
+    adata.uns["scirpy_version"] = "0.7"
 
-    st.tl.chain_qc(adata, key_added=("rec_type", "rec_subtype", "ch_pairing"))
+    ir.tl.chain_qc(adata, key_added=("rec_type", "rec_subtype", "ch_pairing"))
 
     npt.assert_equal(
         adata.obs["rec_type"],
@@ -151,22 +152,26 @@ def test_chain_qc():
 def test_clip_and_count_clonotypes(adata_clonotype):
     adata = adata_clonotype
 
-    res = st._tools._clonal_expansion._clip_and_count(
-        adata, groupby="group", target_col="clonotype", clip_at=2, inplace=False
+    res = ir._tools._clonal_expansion._clip_and_count(
+        adata, groupby="group", target_col="clone_id", clip_at=2, inplace=False
+    )
+    npt.assert_equal(
+        res, np.array([">= 2"] * 3 + ["nan"] * 2 + ["1"] * 3 + [">= 2"] * 2)
     )
-    npt.assert_equal(res, np.array([">= 2"] * 3 + ["1"] * 4 + [">= 2"] * 2))
 
     # check without group
-    res = st._tools._clonal_expansion._clip_and_count(
-        adata, target_col="clonotype", clip_at=5, inplace=False
+    res = ir._tools._clonal_expansion._clip_and_count(
+        adata, target_col="clone_id", clip_at=5, inplace=False
+    )
+    npt.assert_equal(
+        res, np.array(["4"] * 3 + ["nan"] * 2 + ["4"] + ["1"] * 2 + ["2"] * 2)
     )
-    npt.assert_equal(res, np.array(["4"] * 3 + ["1"] + ["4"] + ["1"] * 2 + ["2"] * 2))
 
     # check if target_col works
-    adata.obs["new_col"] = adata.obs["clonotype"]
-    adata.obs.drop("clonotype", axis="columns", inplace=True)
+    adata.obs["new_col"] = adata.obs["clone_id"]
+    adata.obs.drop("clone_id", axis="columns", inplace=True)
 
-    st._tools._clonal_expansion._clip_and_count(
+    ir._tools._clonal_expansion._clip_and_count(
         adata,
         groupby="group",
         target_col="new_col",
@@ -174,35 +179,37 @@ def test_clip_and_count_clonotypes(adata_clonotype):
     )
     npt.assert_equal(
         adata.obs["new_col_clipped_count"],
-        np.array([">= 2"] * 3 + ["1"] * 4 + [">= 2"] * 2),
+        np.array([">= 2"] * 3 + ["nan"] * 2 + ["1"] * 3 + [">= 2"] * 2),
     )
 
     # check if it raises value error if target_col does not exist
     with pytest.raises(ValueError):
-        st._tools._clonal_expansion._clip_and_count(
+        ir._tools._clonal_expansion._clip_and_count(
             adata,
             groupby="group",
-            target_col="clonotype",
+            target_col="clone_id",
             clip_at=2,
             fraction=False,
         )
 
 
-def test_clonal_expansion(adata_clonotype):
-    res = st.tl.clonal_expansion(
-        adata_clonotype, expanded_in="group", clip_at=2, inplace=False
-    )
-    npt.assert_equal(res, np.array([">= 2"] * 3 + ["1"] * 4 + [">= 2"] * 2))
-
-    res = st.tl.clonal_expansion(adata_clonotype, clip_at=2, inplace=False)
-    npt.assert_equal(
-        res, np.array([">= 2"] * 3 + ["1"] + [">= 2"] + ["1"] * 2 + [">= 2"] * 2)
+@pytest.mark.parametrize(
+    "expanded_in,expected",
+    [
+        ("group", [">= 2"] * 3 + ["nan"] * 2 + ["1"] * 3 + [">= 2"] * 2),
+        (None, [">= 2"] * 3 + ["nan"] * 2 + [">= 2"] + ["1"] * 2 + [">= 2"] * 2),
+    ],
+)
+def test_clonal_expansion(adata_clonotype, expanded_in, expected):
+    res = ir.tl.clonal_expansion(
+        adata_clonotype, expanded_in=expanded_in, clip_at=2, inplace=False
     )
+    npt.assert_equal(res, np.array(expected))
 
 
 def test_clonal_expansion_summary(adata_clonotype):
-    res = st.tl.summarize_clonal_expansion(
-        adata_clonotype, "group", target_col="clonotype", clip_at=2, normalize=True
+    res = ir.tl.summarize_clonal_expansion(
+        adata_clonotype, "group", target_col="clone_id", clip_at=2, normalize=True
     )
     pdt.assert_frame_equal(
         res,
@@ -213,10 +220,10 @@ def test_clonal_expansion_summary(adata_clonotype):
     )
 
     # test the `expanded_in` parameter.
-    res = st.tl.summarize_clonal_expansion(
+    res = ir.tl.summarize_clonal_expansion(
         adata_clonotype,
         "group",
-        target_col="clonotype",
+        target_col="clone_id",
         clip_at=2,
         normalize=True,
         expanded_in="group",
@@ -230,13 +237,13 @@ def test_clonal_expansion_summary(adata_clonotype):
     )
 
     # test the `summarize_by` parameter.
-    res = st.tl.summarize_clonal_expansion(
+    res = ir.tl.summarize_clonal_expansion(
         adata_clonotype,
         "group",
-        target_col="clonotype",
+        target_col="clone_id",
         clip_at=2,
         normalize=True,
-        summarize_by="clonotype",
+        summarize_by="clone_id",
     )
     pdt.assert_frame_equal(
         res,
@@ -246,8 +253,8 @@ def test_clonal_expansion_summary(adata_clonotype):
         check_names=False,
     )
 
-    res_counts = st.tl.summarize_clonal_expansion(
-        adata_clonotype, "group", target_col="clonotype", clip_at=2, normalize=False
+    res_counts = ir.tl.summarize_clonal_expansion(
+        adata_clonotype, "group", target_col="clone_id", clip_at=2, normalize=False
     )
     print(res_counts)
     pdt.assert_frame_equal(
@@ -261,12 +268,12 @@ def test_clonal_expansion_summary(adata_clonotype):
 
 
 def test_alpha_diversity(adata_diversity):
-    res = st.tl.alpha_diversity(
+    res = ir.tl.alpha_diversity(
         adata_diversity, groupby="group", target_col="clonotype_", inplace=False
     )
     assert res.to_dict(orient="index") == {"A": {0: 0.0}, "B": {0: 1.0}}
 
-    st.tl.alpha_diversity(
+    ir.tl.alpha_diversity(
         adata_diversity, groupby="group", target_col="clonotype_", inplace=True
     )
     npt.assert_equal(
@@ -285,13 +292,13 @@ def test_group_abundance():
             ["cell4", "B", "ct1"],
             ["cell5", "B", "ct2"],
         ],
-        columns=["cell_id", "group", "clonotype"],
+        columns=["cell_id", "group", "clone_id"],
     ).set_index("cell_id")
     adata = AnnData(obs=obs)
 
     # Check counts
-    res = st.tl.group_abundance(
-        adata, groupby="clonotype", target_col="group", fraction=False
+    res = ir.tl.group_abundance(
+        adata, groupby="clone_id", target_col="group", fraction=False
     )
     expected_count = pd.DataFrame.from_dict(
         {
@@ -303,8 +310,8 @@ def test_group_abundance():
     npt.assert_equal(res.values, expected_count.values)
 
     # Check fractions
-    res = st.tl.group_abundance(
-        adata, groupby="clonotype", target_col="group", fraction=True
+    res = ir.tl.group_abundance(
+        adata, groupby="clone_id", target_col="group", fraction=True
     )
     expected_frac = pd.DataFrame.from_dict(
         {
@@ -316,8 +323,8 @@ def test_group_abundance():
     npt.assert_equal(res.values, expected_frac.values)
 
     # Check swapped
-    res = st.tl.group_abundance(
-        adata, groupby="group", target_col="clonotype", fraction=True
+    res = ir.tl.group_abundance(
+        adata, groupby="group", target_col="clone_id", fraction=True
     )
     expected_frac = pd.DataFrame.from_dict(
         {
@@ -331,15 +338,15 @@ def test_group_abundance():
 
 def test_spectratype(adata_tra):
     # Check numbers
-    res1 = st.tl.spectratype(
+    res1 = ir.tl.spectratype(
         adata_tra,
-        groupby="IR_VJ_1_cdr3",
+        groupby="IR_VJ_1_junction_aa",
         target_col="sample",
         fraction=False,
     )
-    res2 = st.tl.spectratype(
+    res2 = ir.tl.spectratype(
         adata_tra,
-        groupby=("IR_VJ_1_cdr3",),
+        groupby=("IR_VJ_1_junction_aa",),
         target_col="sample",
         fraction=False,
     )
@@ -370,8 +377,8 @@ def test_spectratype(adata_tra):
     npt.assert_equal(res2.values, expected_count.values)
 
     # Check fractions
-    res = st.tl.spectratype(
-        adata_tra, groupby="IR_VJ_1_cdr3", target_col="sample", fraction="sample"
+    res = ir.tl.spectratype(
+        adata_tra, groupby="IR_VJ_1_junction_aa", target_col="sample", fraction="sample"
     )
     expected_frac = pd.DataFrame.from_dict(
         {
@@ -400,7 +407,7 @@ def test_spectratype(adata_tra):
 
 
 def test_repertoire_overlap(adata_tra):
-    res, d, l = st.tl.repertoire_overlap(adata_tra, "sample", inplace=False)
+    res, d, l = ir.tl.repertoire_overlap(adata_tra, "sample", inplace=False)
     expected_cnt = pd.DataFrame.from_dict(
         {
             1: {
@@ -458,7 +465,7 @@ def test_repertoire_overlap(adata_tra):
 
 
 def test_clonotype_imbalance(adata_tra):
-    freq, stat = st.tl.clonotype_imbalance(
+    freq, stat = ir.tl.clonotype_imbalance(
         adata_tra[
             adata_tra.obs.index.isin(
                 [
@@ -478,175 +485,175 @@ def test_clonotype_imbalance(adata_tra):
     expected_freq = pd.DataFrame.from_dict(
         {
             0: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             1: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             2: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "3",
                 "Normalized abundance": 1.0,
             },
             3: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             4: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "3",
                 "Normalized abundance": 1.0,
             },
             5: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             6: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             7: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "3",
                 "Normalized abundance": 1.0,
             },
             8: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "1",
                 "Normalized abundance": 0.0,
             },
             9: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "3",
                 "Normalized abundance": 1.0,
             },
             10: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             11: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             12: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "3",
                 "Normalized abundance": 0.0,
             },
             13: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             14: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "3",
                 "Normalized abundance": 0.0,
             },
             15: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             16: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             17: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "3",
                 "Normalized abundance": 0.0,
             },
             18: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             19: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "3",
                 "Normalized abundance": 0.0,
             },
             20: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             21: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             22: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 None: "All",
                 "chain_pairing": "Background",
                 "sample": "3",
                 "Normalized abundance": 0.0,
             },
             23: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "1",
                 "Normalized abundance": 1.0,
             },
             24: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 None: "All",
                 "chain_pairing": "Single pair",
                 "sample": "3",
@@ -655,7 +662,7 @@ def test_clonotype_imbalance(adata_tra):
         },
         orient="index",
     )
-    freq = freq.sort_values(by=["clonotype", "chain_pairing", "sample"])
+    freq = freq.sort_values(by=["clone_id", "chain_pairing", "sample"])
     freq = freq.reset_index().iloc[:, 1:6]
     print(freq)
     print(stat)
@@ -663,31 +670,31 @@ def test_clonotype_imbalance(adata_tra):
     expected_stat = pd.DataFrame.from_dict(
         {
             0: {
-                "clonotype": "clonotype_330",
+                "clone_id": "clonotype_330",
                 "pValue": 1.0,
                 "logpValue": -0.0,
                 "logFC": 0.5849625007211562,
             },
             1: {
-                "clonotype": "clonotype_458",
+                "clone_id": "clonotype_458",
                 "pValue": 1.0,
                 "logpValue": -0.0,
                 "logFC": 0.5849625007211562,
             },
             2: {
-                "clonotype": "clonotype_739",
+                "clone_id": "clonotype_739",
                 "pValue": 1.0,
                 "logpValue": -0.0,
                 "logFC": -0.4150374992788438,
             },
             3: {
-                "clonotype": "clonotype_986",
+                "clone_id": "clonotype_986",
                 "pValue": 1.0,
                 "logpValue": -0.0,
                 "logFC": -0.4150374992788438,
             },
             4: {
-                "clonotype": "clonotype_987",
+                "clone_id": "clonotype_987",
                 "pValue": 1.0,
                 "logpValue": -0.0,
                 "logFC": -0.4150374992788438,
@@ -695,6 +702,6 @@ def test_clonotype_imbalance(adata_tra):
         },
         orient="index",
     )
-    stat = stat.sort_values(by="clonotype")
+    stat = stat.sort_values(by="clone_id")
     stat = stat.reset_index().iloc[:, 1:5]
     pdt.assert_frame_equal(stat, expected_stat, check_names=False, check_dtype=False)
